---
title: 페이팔 해외결제 서비스 이용안내
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 해외결제
seo:
  title: 페이팔 해외결제 서비스 이용안내
  description: >-
    해외 각국의 결제수단을 다양하게 제공하는 페이팔 서비스 안내드립니다. 가입방법, 결제방식, 결제수단, 입점기준, 결제 수수료, 지원통화,
    정산방법, 문의처, 연동가이드, 고위험 산업(STC) 연동까지 모두 확인해보세요.
  keywords:
    - 해외결제
tags:
  - 페이팔
  - 해외결제
pgCompanies:
  - 페이팔
searchTags:
  - 페이팔 서비스
  - 페이팔 정기결제
  - 페이팔 일반결제
  - 페이팔 해외결제
  - 해외결제
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="페이팔을 통한 해외결제 이용방법 안내드립니다." />

#### **페이팔의 해외결제 서비스 이용안내**

- 지원 결제방식 : 일반결제(Smart Payment Buttons) / 정기결제(Reference Transaction)
- 결제수단 : 카드. 페이팔 머니
- 지원통화 : 페이팔이 지원하는 화폐범위 결제가능
  - [페이팔 지원 통화 보러가기↗](https://developer.paypal.com/docs/reports/reference/paypal-supported-currencies/)
- 결제수수료 : 2.9%\~4.4% + $0.30 USD (수수료는 페이팔 내부정책에 따름)
- 정산방법 : 페이팔 정산은 언제든지 계정의 잔고를 본인의 계좌로 직접 이체하여 출금하는 방법으로 이용할 수 있습니다.
- 페이팔 국내 고객센터 : 02-3483-1131
- 참고사항 : 페이팔은 판매자계정과 구매자계정의 국가가 모두 한국일 경우 결제실패가 발생됩니다. \
  따라서, 국내 사업자로 설정되어있는 고객사일 경우 해외고객들을 대상으로한 결제만 이용하실 수 있습니다.  단, RT(정기결제)방식은 ‘국내 판매자’인 경우 ‘해외 구매자’만 이용 가능합니다.

#### **페이팔 STC(고위험 산업) 연동 안내**

페이팔 내부적으로 “고위험 산업”(게임과 같은 디지털 상품, 중고거래)의 경우에는 페이팔의 STC API를 통해 판매자 보호 정책을 적용하는 것을 페이팔에서 필수로 요구하고 있습니다.

판매자 보호 정책에 관한 자세한 내용과 협의가 필요하시다면 페이팔 측에 직접 문의를 주셔야 하니 이용에 참고 부탁 드립니다. (’고위험 산업’이 아닌 경우에도 STC API를 연동하는 것을 권장하고 있습니다)

고위험 산업 에 해당하는 산업군

1. 이벤트/티켓 판매 산업

2\. 연료 산업

3\. 게임/디지털 상품 산업

4\. 마켓플레이스 사업

5\. 온라인 여행 산업(렌터카, 숙박, 여행 패키지, 교통)

6\. P2P 산업

7\. 소매, 식품 산업

<Indent level="1">

- ‘소매, 식품 산업’의 연동이 필요한 유형
- 모바일 기기를 통해 매장 내 구매가 가능한 산업
- ‘소매, 식품 산업’의 연동이 필요하지 않은 유형
  - 타사 배송업체를 통해 주소로 실물 상품을 배송하는 산업
  - 자체 배송 트럭을 통해 주소로 실물 상품을 배송하는 산업
  - 소비자가 수령할 수 있도록 자체 매장에서 실물 상품을 배송하는 산업

</Indent>

8\. 택시, 공유 이동수단 사업

9\. 통신사

10\. 결제 시스템 보안 서비스 산업

#### **페이팔 STC(고위험 산업) 연동 가이드**

- [고위험 거래 상세 정보(산업군별 파라미터) 연동 가이드 보러가기↗](https://developers.portone.io/opi/ko/integration/pg/v1/spb/stc?v=v1)

<Callout title="V2 페이팔 연동가이드 보러가기↗" />

<Callout title="V1 페이팔(Smart Payment Button) 연동가이드 보러가기↗" />

<Callout title="V1 페이팔(Referenct Transaction) 연동가이드 보러가기↗" />
